@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2005-2006  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2005-2007  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,6 @@ static GtkWidget *tree;
 static GtkWidget *statusbar;
 static GtkWidget *progress;
 static GtkWidget *treeview;
-static GtkWidget *iconview;
 
 static gboolean periodic_running = FALSE;
 
@@ -155,23 +154,6 @@ static void periodic_callback(GtkWidget *widget, gpointer user_data)
 	}
 }
 
-static void toggled_callback(GtkWidget *button, gpointer user_data)
-{
-	gboolean mode;
-
-	mode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-
-	if (mode == TRUE) {
-		gtk_widget_hide(GTK_WIDGET(treeview));
-		gtk_widget_show(GTK_WIDGET(iconview));
-		gtk_widget_hide(GTK_WIDGET(sort));
-	} else {
-		gtk_widget_show(GTK_WIDGET(sort));
-		gtk_widget_hide(GTK_WIDGET(iconview));
-		gtk_widget_show(GTK_WIDGET(treeview));
-	}
-}
-
 static void sort_callback(GtkWidget *button, gpointer user_data)
 {
 	gboolean mode;
@@ -191,7 +173,7 @@ static void class_to_text(GtkTreeViewColumn *column, GtkCellRenderer *cell,
 	gboolean valid;
 	gchar *str;
 
-	gtk_tree_model_get(model, iter, 2, &class, 6, &valid, -1);
+	gtk_tree_model_get(model, iter, 2, &class, 5, &valid, -1);
 
 	if (class != 0 && valid == TRUE) {
 		str = g_strdup_printf("0x%06x", class);
@@ -238,9 +220,7 @@ static void create_window(DBusGConnection *conn)
 {
 	GtkWidget *window;
 	GtkWidget *scrolled;
-	GtkWidget *icon;
 	GtkWidget *vbox;
-	GtkWidget *toggle;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
@@ -281,7 +261,7 @@ static void create_window(DBusGConnection *conn)
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes(column, renderer, "text", 1, NULL);
-	gtk_tree_view_column_add_attribute(column, renderer, "sensitive", 6);
+	gtk_tree_view_column_add_attribute(column, renderer, "sensitive", 5);
 
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree), column);
 
@@ -330,25 +310,6 @@ static void create_window(DBusGConnection *conn)
 
 	treeview = scrolled;
 
-	scrolled = gtk_scrolled_window_new(NULL, NULL);
-
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
-				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-
-	gtk_container_add(GTK_CONTAINER(vbox), scrolled);
-
-	icon = gtk_icon_view_new_with_model(GTK_TREE_MODEL(store));
-
-	gtk_icon_view_set_text_column(GTK_ICON_VIEW(icon), 1);
-
-	gtk_icon_view_set_pixbuf_column(GTK_ICON_VIEW(icon), 5);
-
-	gtk_icon_view_set_item_width(GTK_ICON_VIEW(icon), 120);
-
-	gtk_container_add(GTK_CONTAINER(scrolled), icon);
-
-	iconview = scrolled;
-
 	sort = gtk_check_button_new_with_label(_("Sort by RSSI"));
 
 	g_signal_connect(G_OBJECT(sort), "toggled",
@@ -356,13 +317,6 @@ static void create_window(DBusGConnection *conn)
 
 	gtk_box_pack_start(GTK_BOX(vbox), sort, FALSE, FALSE, 0);
 
-	toggle = gtk_check_button_new_with_label(_("Icon view"));
-
-	g_signal_connect(G_OBJECT(toggle), "toggled",
-				G_CALLBACK(toggled_callback), NULL);
-
-	gtk_box_pack_start(GTK_BOX(vbox), toggle, FALSE, FALSE, 0);
-
 	periodic = gtk_check_button_new_with_label(_("Periodic discovery"));
 
 	g_signal_connect(G_OBJECT(periodic), "toggled",
@@ -408,40 +362,42 @@ static void create_window(DBusGConnection *conn)
 	gtk_widget_hide(cancel);
 
 	gtk_widget_hide(GTK_WIDGET(progress));
-
-	gtk_widget_hide(GTK_WIDGET(iconview));
 }
 
 static void remote_device_found(DBusGProxy *object, const char *address,
 		const unsigned int class, const int rssi, gpointer user_data)
 {
-	DBusGConnection *conn = user_data;
+	//DBusGConnection *conn = user_data;
 
 	gtk_progress_bar_pulse(GTK_PROGRESS_BAR(progress));
 
 	bluetooth_device_store_add_device(BLUETOOTH_DEVICE_STORE(store),
 							address, class, rssi);
 
+#if 0
 	object = dbus_g_proxy_new_for_name(conn, "org.bluez",
 				"/org/bluez/hci0", "org.bluez.Test");
 
 	dbus_g_proxy_call(object, "AuditRemoteDevice", NULL,
 				G_TYPE_STRING, address, G_TYPE_INVALID);	
+#endif
 }
 
 static void remote_device_disappeared(DBusGProxy *object,
 				const char *address, gpointer user_data)
 {
-	DBusGConnection *conn = user_data;
+	//DBusGConnection *conn = user_data;
 
 	bluetooth_device_store_del_device(BLUETOOTH_DEVICE_STORE(store),
 								address);
 
+#if 0
 	object = dbus_g_proxy_new_for_name(conn, "org.bluez",
 				"/org/bluez/hci0", "org.bluez.Test");
 
 	dbus_g_proxy_call(object, "CancelAuditRemoteDevice", NULL,
 				G_TYPE_STRING, address, G_TYPE_INVALID);	
+#endif
 }
 
 static void remote_name_updated(DBusGProxy *object, const char *address,
@@ -562,7 +518,7 @@ int main(int argc, char *argv[])
 
 	conn = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
 	if (error != NULL) {
-		g_printerr(_("Connecting to system bus failed: %s\n"),
+		g_printerr("Connecting to system bus failed: %s\n",
 							error->message);
 		g_error_free(error);
 		exit(EXIT_FAILURE);
