@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2005-2006  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2005-2007  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,9 +25,7 @@
 #include <config.h>
 #endif
 
-#include <stdio.h>
-#include <errno.h>
-#include <stdlib.h>
+#include <string.h>
 
 #include <dbus/dbus-glib.h>
 
@@ -35,9 +33,64 @@
 
 #include <gtk/gtk.h>
 
-#include "device-store.h"
+#include "client.h"
 
-static DBusGConnection *conn;
+#include "dbus-glue.h"
+
+#include "bluetooth-device-selection.h"
+
+static BluetoothClient *client;
+
+static gchar *address = NULL;
+static gchar *passkey = "123456";
+
+static GtkWidget *page_search = NULL;
+static GtkWidget *page_info = NULL;
+static GtkWidget *page_pairing = NULL;
+static GtkWidget *page_summary = NULL;
+
+static GtkWidget *label_pairing = NULL;
+static GtkWidget *label_passkey = NULL;
+
+static GtkWidget *selector = NULL;
+
+static gboolean passkey_agent_request(GObject *agent,
+				const char *path, const char *address,
+					DBusGMethodInvocation *context)
+{
+	const char *value = passkey;
+
+	/* Apple Wireless and Mighty Mouse */
+	if (strncasecmp(address, "00:0A:95:", 9) == 0 ||
+				strncasecmp(address, "00:14:51:", 9) == 0)
+		value = "0000";
+
+	dbus_g_method_return(context, value);
+
+	return TRUE;
+}
+
+static gboolean passkey_agent_confirm(GObject *agent,
+			const char *path, const char *address,
+			const char *value, DBusGMethodInvocation *context)
+{
+	dbus_g_method_return(context);
+
+	return TRUE;
+}
+
+static gboolean passkey_agent_cancel(GObject *agent,
+			const char *path, const char *address, GError **error)
+{
+	return TRUE;
+}
+
+static gboolean passkey_agent_release(GObject *agent, GError **error)
+{
+	return TRUE;
+}
+
+#include "passkey-agent-glue.h"
 
 #if 0
 static gint page_forward(gint current_page, gpointer data)
@@ -60,6 +113,31 @@ static void cancel_callback(GtkWidget *assistant, gpointer data)
 	gtk_main_quit();
 }
 
+static void prepare_callback(GtkWidget *assistant,
+				GtkWidget *page, gpointer data)
+{
+	if (page == page_search) {
+		bluetooth_device_selection_start_discovery(BLUETOOTH_DEVICE_SELECTION(selector));
+		return;
+	}
+
+	if (page == page_pairing) {
+		bluetooth_client_cancel_discovery(client, NULL);
+
+		bluetooth_client_register_passkey_agent(client,
+					"/org/bluez/applet", address,
+					&dbus_glib_passkey_agent_object_info);
+
+		bluetooth_client_create_bonding(client, NULL, address);
+
+		gtk_label_set_markup(GTK_LABEL(label_pairing), address);
+		gtk_label_set_markup(GTK_LABEL(label_passkey), passkey);
+		return;
+	}
+
+	gtk_assistant_set_page_complete(GTK_ASSISTANT(assistant), page, TRUE);
+}
+
 static GtkWidget *create_vbox(GtkWidget *assistant, GtkAssistantPageType type,
 				const gchar *title, const gchar *section)
 {
@@ -82,8 +160,6 @@ static GtkWidget *create_vbox(GtkWidget *assistant, GtkAssistantPageType type,
 
 	g_free(str);
 
-	gtk_assistant_set_page_complete(GTK_ASSISTANT(assistant), vbox, TRUE);
-
 	//pixbuf = gtk_widget_render_icon(GTK_WIDGET(assistant),
 	//		GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG, NULL);
 
@@ -116,6 +192,9 @@ static void create_intro(GtkWidget *assistant)
 {
 	GtkWidget *vbox;
 	GtkWidget *label;
+	GtkWidget *combo;
+	GtkTreeModel *model;
+	GtkCellRenderer *renderer;
 
 	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_INTRO,
 			_("Introduction"),
@@ -126,7 +205,7 @@ static void create_intro(GtkWidget *assistant)
 	gtk_label_set_markup(GTK_LABEL(label), _("The device wizard will "
 				"walk you through the process of configuring "
 				"Bluetooth enabled devices for use with this "
-				"computer."));
+				"computer.\n\n"));
 
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 
@@ -135,6 +214,28 @@ static void create_intro(GtkWidget *assistant)
 	gtk_widget_set_size_request(GTK_WIDGET(label), 380, -1);
 
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
+
+	combo = gtk_combo_box_new();
+
+	model = bluetooth_client_get_model_adapter_list(client);
+
+	gtk_combo_box_set_model(GTK_COMBO_BOX(combo), model);
+
+	g_object_unref(model);
+
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(combo));
+
+	renderer = gtk_cell_renderer_text_new();
+
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo), renderer, TRUE);
+
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo), renderer,
+						"text", COLUMN_NAME, NULL);
+
+	if (gtk_tree_model_iter_n_children(model, NULL) > 1)
+		gtk_box_pack_start(GTK_BOX(vbox), combo, FALSE, FALSE, 0);
 }
 
 static void create_type(GtkWidget *assistant)
@@ -144,14 +245,14 @@ static void create_type(GtkWidget *assistant)
 	GSList *group = NULL;
 
 	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_CONTENT,
-				_("Device type"),
-				_("Select type of device you wanna setup"));
+			_("Device type"),
+			_("Select the type of device you want to setup"));
 
 	button = gtk_radio_button_new_with_label(group, _("Mouse"));
 
 	group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
 
-	gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+	//gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
 
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
@@ -159,7 +260,7 @@ static void create_type(GtkWidget *assistant)
 
 	group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
 
-	gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+	//gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
 
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
 
@@ -196,75 +297,83 @@ static void create_type(GtkWidget *assistant)
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
 }
 
-static void create_list(GtkWidget *assistant)
+static void select_callback(BluetoothDeviceSelection *sel,
+				gchar *selected, gpointer user_data)
+{
+	GtkAssistant *assistant = user_data;
+
+	if (selected != NULL) {
+		g_free(address);
+
+		address = g_strdup(selected);
+
+		gtk_assistant_set_page_complete(assistant, page_search, TRUE);
+	} else
+		gtk_assistant_set_page_complete(assistant, page_search, FALSE);
+}
+
+static void create_search(GtkWidget *assistant)
 {
 	GtkWidget *vbox;
-	GtkWidget *tree;
-	GtkWidget *scrolled;
-	GtkTreeModel *store;
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
 
-	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_PROGRESS,
+	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_CONTENT,
 				_("Device search"),
-				_("Select device you wanna setup"));
+				_("Select the device you want to setup"));
 
-	scrolled = gtk_scrolled_window_new(NULL, NULL);
+	selector = bluetooth_device_selection_new(NULL);
 
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
-				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	g_signal_connect(selector, "selected-device-changed",
+				G_CALLBACK(select_callback), assistant);
 
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled),
-							GTK_SHADOW_OUT);
+	gtk_container_add(GTK_CONTAINER(vbox), selector);
 
-	gtk_container_add(GTK_CONTAINER(vbox), scrolled);
+	page_search = vbox;
+}
 
-	tree = gtk_tree_view_new();
+static void create_info(GtkWidget *assistant)
+{
+	GtkWidget *vbox;
+	GtkWidget *label;
 
-	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree), TRUE);
+	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_CONTENT,
+				_("Device information"),
+				_("Gathering information about device"));
 
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tree), TRUE);
+	label = gtk_label_new(NULL);
 
-	column = gtk_tree_view_column_new();
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 
-	gtk_tree_view_column_set_title(column, "Device");
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
-	renderer = gtk_cell_renderer_pixbuf_new();
-	gtk_tree_view_column_set_spacing(column, 4);
-	gtk_tree_view_column_pack_start(column, renderer, FALSE);
-	gtk_tree_view_column_add_attribute(column, renderer, "icon-name", 4);
+	page_info = vbox;
+}
 
-	renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer, "text", 1, NULL);
-	gtk_tree_view_column_add_attribute(column, renderer, "sensitive", 6);
+static void create_pairing(GtkWidget *assistant)
+{
+	GtkWidget *vbox;
+	GtkWidget *label;
 
-	gtk_tree_view_append_column(GTK_TREE_VIEW(tree), column);
+	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_CONTENT,
+				_("Device pairing"),
+				_("Pairing with new device"));
 
-        gtk_tree_view_column_set_min_width(GTK_TREE_VIEW_COLUMN(column), 280);
+	label = gtk_label_new(NULL);
 
-	column = gtk_tree_view_column_new();
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 
-	gtk_tree_view_column_set_title(column, "Type");
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
-        renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer, "text", 2, NULL);
-	gtk_tree_view_column_add_attribute(column, renderer, "sensitive", 6);
+	label_pairing = label;
 
-	gtk_tree_view_append_column(GTK_TREE_VIEW(tree), column);
+	label = gtk_label_new(NULL);
 
-	store = GTK_TREE_MODEL(bluetooth_device_store_new());
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 
-	gtk_tree_view_set_model(GTK_TREE_VIEW(tree), GTK_TREE_MODEL(store));
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
-	gtk_container_add(GTK_CONTAINER(scrolled), tree);
+	label_passkey = label;
 
-	bluetooth_device_store_add_device(BLUETOOTH_DEVICE_STORE(store),
-					"00:11:22:33:44:55", 0x000100, 0);
-
-	bluetooth_device_store_add_name(BLUETOOTH_DEVICE_STORE(store),
-					"00:11:22:33:44:55", "Test device");
+	page_pairing = vbox;
 }
 
 static void create_summary(GtkWidget *assistant)
@@ -274,6 +383,8 @@ static void create_summary(GtkWidget *assistant)
 	vbox = create_vbox(assistant, GTK_ASSISTANT_PAGE_SUMMARY,
 				_("Summary"),
 				_("Succesfully configured new device"));
+
+	page_summary = vbox;
 }
 
 static void create_wizard(void)
@@ -282,13 +393,13 @@ static void create_wizard(void)
 
 	assistant = gtk_assistant_new();
 
-	gtk_window_set_title(GTK_WINDOW(assistant), _("Bluetooth device wizard"));
+	gtk_window_set_title(GTK_WINDOW(assistant), _("Bluetooth Device Wizard"));
 
 	gtk_window_set_icon_name(GTK_WINDOW(assistant), "stock_bluetooth");
 
-        gtk_window_set_position(GTK_WINDOW(assistant), GTK_WIN_POS_CENTER);
+	gtk_window_set_position(GTK_WINDOW(assistant), GTK_WIN_POS_CENTER);
 
-        gtk_window_set_default_size(GTK_WINDOW(assistant), 440, 440);
+	gtk_window_set_default_size(GTK_WINDOW(assistant), 440, 440);
 
 #if 0
 	gtk_assistant_set_forward_page_func(GTK_ASSISTANT(assistant),
@@ -299,7 +410,11 @@ static void create_wizard(void)
 
 	create_type(assistant);
 
-	create_list(assistant);
+	create_search(assistant);
+
+	create_info(assistant);
+
+	create_pairing(assistant);
 
 	create_summary(assistant);
 
@@ -309,6 +424,9 @@ static void create_wizard(void)
 	g_signal_connect(G_OBJECT(assistant), "cancel",
 					G_CALLBACK(cancel_callback), NULL);
 
+	g_signal_connect(G_OBJECT(assistant), "prepare",
+					G_CALLBACK(prepare_callback), NULL);
+
 	gtk_widget_show_all(assistant);
 
 	gtk_assistant_update_buttons_state(GTK_ASSISTANT(assistant));
@@ -316,27 +434,19 @@ static void create_wizard(void)
 
 int main(int argc, char *argv[])
 {
-	GError *error = NULL;
-
 	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
 	gtk_init(&argc, &argv);
 
-	conn = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
-	if (error != NULL) {
-		g_printerr(_("Connecting to system bus failed: %s\n"),
-							error->message);
-		g_error_free(error);
-		exit(EXIT_FAILURE);
-	}
+	client = bluetooth_client_new();
 
 	create_wizard();
 
 	gtk_main();
 
-	dbus_g_connection_unref(conn);
+	g_object_unref(client);
 
 	return 0;
 }
